self.__BUILD_MANIFEST=function(s,c,a,e,t,u,n,b,f,i,j,o,r,k,d,h){return{__rewrites:{afterFiles:[],beforeFiles:[],fallback:[]},"/":["static/chunks/pages/index-444f1804401f04ea.js"],"/_error":["static/chunks/pages/_error-c66a4e8afc46f17b.js"],"/clusters":["static/chunks/pages/clusters-5e4a3838b630b282.js"],"/clusters/[cluster]":[c,s,a,f,u,i,b,e,t,n,j,o,r,k,d,"static/chunks/6856-da20c5fd999f319c.js","static/chunks/1871-85937ae7094088a5.js","static/chunks/pages/clusters/[cluster]-cb2d6ffe802fb8da.js"],"/clusters/[cluster]/[job]":[c,s,a,e,t,h,"static/chunks/pages/clusters/[cluster]/[job]-351c45b1bb05a3b4.js"],"/config":["static/chunks/pages/config-718cdc365de82689.js"],"/infra":["static/chunks/pages/infra-dd57b6695972c83d.js"],"/infra/[context]":["static/chunks/pages/infra/[context]-68a1821fb01ac14d.js"],"/jobs":["static/chunks/pages/jobs-a94fb2b242778bf7.js"],"/jobs/pools/[pool]":[c,s,a,u,b,"static/chunks/8821-93c25df904a8362b.js",e,t,n,"static/chunks/pages/jobs/pools/[pool]-d77370697311e9ea.js"],"/jobs/[job]":[c,s,a,u,b,e,t,n,h,"static/chunks/pages/jobs/[job]-4842e87e8ba8ba2d.js"],"/plugins/[...slug]":[s,"static/chunks/pages/plugins/[...slug]-4f46050ca065d8f8.js"],"/users":["static/chunks/pages/users-932c74545c13bf64.js"],"/volumes":["static/chunks/pages/volumes-6eee881fb02d60ea.js"],"/workspace/new":["static/chunks/pages/workspace/new-3f88a1c7e86a3f86.js"],"/workspaces":["static/chunks/pages/workspaces-b4ba66a524d42b9e.js"],"/workspaces/[name]":[c,s,a,f,u,i,e,t,n,j,o,r,k,d,"static/chunks/8050-070f4c1b7ad40a8c.js","static/chunks/pages/workspaces/[name]-c0782cda98c88b4b.js"],sortedPages:["/","/_app","/_error","/clusters","/clusters/[cluster]","/clusters/[cluster]/[job]","/config","/infra","/infra/[context]","/jobs","/jobs/pools/[pool]","/jobs/[job]","/plugins/[...slug]","/users","/volumes","/workspace/new","/workspaces","/workspaces/[name]"]}}("static/chunks/5739-d67458fcb1386c92.js","static/chunks/616-3d59f75e2ccf9321.js","static/chunks/6130-2be46d70a38f1e82.js","static/chunks/6989-848d44d7a6ea601d.js","static/chunks/3850-fd5696f3bbbaddae.js","static/chunks/1272-1ef0bf0237faccdb.js","static/chunks/8969-2d2b2903aa947bd4.js","static/chunks/754-d0da8ab45f9509e9.js","static/chunks/6082-edabd8f6092300ce.js","static/chunks/2521-099b07cd9e4745bf.js","static/chunks/6990-944fedb5fea1cf7a.js","static/chunks/4973-be568fc06fd40af0.js","static/chunks/9353-c5216858c8eae0fa.js","static/chunks/3800-12692947d0cccd97.js","static/chunks/2109-87285af467b25239.js","static/chunks/4083-4ccd1aa2daef5482.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();